@@ -2,9 +2,7 @@ import os
 import glob
 import yaml
 import chevron
-import argparse
 import json
-import importlib.util
 from requests import Session
 from authenticate import Authenticate
 from urllib.parse import urljoin
@@ -96,26 +94,3 @@ class Runner(Authenticate):
             **self.get_kwargs()
         )
         return self.parse_response(response)
-
-
-def main():
-    parser = argparse.ArgumentParser()
-    parser.add_argument('action', help='The connector action to run')
-    args = parser.parse_args()
-
-    # check if action has an override script
-    glob_path = '../**/{}.py'.format(args.action)
-    action_override = glob.glob(glob_path, recursive=True)
-    if action_override and len(action_override) == 1:
-        spec = importlib.util.spec_from_file_location("module.name", action_override[0])
-        mod = importlib.util.module_from_spec(spec)
-        spec.loader.exec_module(mod)
-        resp = mod.RunnerOverride(args.action).run()
-    else:
-        resp = Runner(args.action).run()
-    print('::set-output {}'.format(resp))
-    return resp
-
-
-if __name__ == 'main':
-    main()
